summary refs log tree commit diff
path: root/pkgs/desktops
diff options
context:
space:
mode:
authorworldofpeace <worldofpeace@protonmail.ch>2019-08-08 11:00:39 -0400
committerworldofpeace <worldofpeace@protonmail.ch>2020-01-07 20:13:27 -0500
commit02543efd835a9ce0548118ec3c36c20abfedff2b (patch)
tree57a3ba4ed784c6fec2ea48f0078eff620714c362 /pkgs/desktops
parent62095621d7a953f4e6da9d857a90200dce8c7707 (diff)
downloadnixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar.gz
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar.bz2
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar.lz
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar.xz
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.tar.zst
nixpkgs-02543efd835a9ce0548118ec3c36c20abfedff2b.zip
deepin.dde-session-ui: use gapps wrapper
Forgot about wrapQtAppsHook only wrapping
binaries that are ELF headers. So it can't wrap
it if it already is.
Diffstat (limited to 'pkgs/desktops')
-rw-r--r--pkgs/desktops/deepin/dde-session-ui/default.nix12
1 files changed, 10 insertions, 2 deletions
diff --git a/pkgs/desktops/deepin/dde-session-ui/default.nix b/pkgs/desktops/deepin/dde-session-ui/default.nix
index 699403567b7..a664defae56 100644
--- a/pkgs/desktops/deepin/dde-session-ui/default.nix
+++ b/pkgs/desktops/deepin/dde-session-ui/default.nix
@@ -104,10 +104,18 @@ mkDerivation rec {
     # - do not wrap dde-dman-portal related files: it appears it has been removed: https://github.com/linuxdeepin/dde-session-ui/commit/3bd028cf135ad22c784c0146e447ef34a69af768
   '';
 
+  dontWrapQtApps = true;
+
+  preFixup = ''
+    gappsWrapperArgs+=(
+      "''${qtWrapperArgs[@]}"
+    )
+  '';
+
   postFixup = ''
     # wrapGAppsHook does not work with binaries outside of $out/bin or $out/libexec
     for binary in $out/lib/deepin-daemon/*; do
-      wrapProgram $binary "''${qtWrapperArgs[@]}"
+      wrapProgram $binary "''${gappsWrapperArgs[@]}"
     done
 
     searchHardCodedPaths $out  # debugging
@@ -104,10 +104,18 @@ mkDerivation rec {
   postFixup = ''
-    # wrapGAppsHook does not work with binaries outside of $out/bin or $out/libexec
+    # wrapGAppsHook or wrapQtAppsHook does not work with binaries outside of $out/bin or $out/libexec
     for binary in $out/lib/deepin-daemon/*; do